﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace lucere.analysis
{
    /// <summary> Filters {@link StandardTokenizer} with {@link StandardFilter},
    /// {@link LowerCaseFilter} and {@link StopFilter}, using a list of English stop
    /// words.
    /// 
    /// <a name="version"/>
    /// <p/>
    /// You must specify the required {@link Version} compatibility when creating
    /// StandardAnalyzer:
    /// <ul>
    /// <li>As of 2.9, StopFilter preserves position increments</li>
    /// <li>As of 2.4, Tokens incorrectly identified as acronyms are corrected (see
    /// <a href="https://issues.apache.org/jira/browse/LUCENE-1068">LUCENE-1608</a></li>
    /// </ul>
    /// 
    /// </summary>
    public interface IStandardAnalyzer : IAnalyzer
    {
        /// <summary> Get/Set maximum allowed token length.  If a token is seen
        /// that exceeds this length then it is discarded.  This
        /// setting only takes effect the next time tokenStream or
        /// reusableTokenStream is called.
        /// </summary>
        int MaxTokenLength { get; set; }
    }
}
